$wnd.rstudio.runAsyncCallback3("function Mpi(a){this.a=a}\nfunction Opi(a){this.a=a}\nfunction Xpi(a){this.a=a}\nfunction Hre(a,b){var c;for(c=0;c<a.p.a.length;c++){if(Pgd(a.p,c).MM==b){ete(a.s,cId(c));break}}}\nfunction Lpi(a,b){this.c=a;this.b=e9h(a.c,pUn,qUn,ain).pF();this.a=e9h(a.c,rUn,sUn,tUn).pF();Yh(b,new Mpi(this),IA?IA:(IA=new by))}\nfunction Jpi(a){var b;b=Kpi(a,'weaving Rnw files',a.b,e9h(a.c.c,pUn,qUn,ain));b||Kpi(a,'LaTeX typesetting',a.a,e9h(a.c.c,rUn,sUn,tUn))}\nfunction Hpi(a,b,c){var d;d=qki(a.b.a);Mre(d,Ebi(Bvg((yff(),xff).a)));!!b&&Hre(d,b);Sre(d,c);Ije(d,true);new Lpi(a,d);($lf()||!!$wnd.remoteDesktop)&&cmf()}\nfunction Tpi(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=Nwi(a.a.b.a));switch(a.c){case 1:Hpi(a.a.a,null,true);break;case 2:Hpi(a.a.a,a.b[0],LGd(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nfunction Kpi(a,b,c,d){if(dH(c)!==dH(d.pF())&&dH(d.eq())!==dH(d.pF())){u_d(2,'Project Option Unchanged','You changed the global option for '+b+$fn+d.pF()+', however the current project is '+'still configured to use '+d.eq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new Opi(a),true);return true}else{return false}}\nN$c(2818,1,{},Lpi);var tQb=dHd(2818);N$c(2819,1,ven,Mpi);_.fn=function Npi(a){Jpi(this.a)};var rQb=dHd(2819);N$c(2820,1,Ygn,Opi);_.zm=function Ppi(){f5d(this.a.c.a.Ug)};var sQb=dHd(2820);N$c(626,1,EGn);_.xm=function Wpi(){Tpi((new Xpi(this)).a)};N$c(2874,1,ygn,Xpi);_.zm=function Ypi(){Tpi(this.a)};var uQb=dHd(2874);u7m(Gl)(3);\n//# sourceURL=rstudio-3.js\n")
