$wnd.rstudio.runAsyncCallback3("function ZLi(a){this.a=a}\nfunction _Li(a){this.a=a}\nfunction iMi(a){this.a=a}\nfunction kxe(a,b){var c;for(c=0;c<a.p.a.length;c++){if(zld(a.p,c).CP==b){_ze(a.s,zNd(c));break}}}\nfunction YLi(a,b){this.c=a;this.b=rvi(a.c,Rko,Sko,xGn).EH();this.a=rvi(a.c,Tko,Uko,Vko).EH();Yh(b,new ZLi(this),AD?AD:(AD=new VA))}\nfunction WLi(a){var b;b=XLi(a,'weaving Rnw files',a.b,rvi(a.c.c,Rko,Sko,xGn));b||XLi(a,'LaTeX typesetting',a.a,rvi(a.c.c,Tko,Uko,Vko))}\nfunction ULi(a,b,c){var d;d=DGi(a.b.a);pxe(d,Rxi(NPg((Pyf(),Oyf).a)));!!b&&kxe(d,b);vxe(d,c);kpe(d,true);new YLi(a,d);(pFf()||!!$wnd.remoteDesktop)&&tFf()}\nfunction eMi(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=ZSi(a.a.b.a));switch(a.c){case 1:ULi(a.a.a,null,true);break;case 2:ULi(a.a.a,a.b[0],gMd(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nfunction XLi(a,b,c,d){if(ZJ(c)!==ZJ(d.EH())&&ZJ(d.Jq())!==ZJ(d.EH())){Y4d(2,'Project Option Unchanged','You changed the global option for '+b+vEn+d.EH()+', however the current project is '+'still configured to use '+d.Jq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new _Li(a),true);return true}else{return false}}\nS2c(2842,1,{},YLi);var XTb=AMd(2842);S2c(2843,1,SCn,ZLi);_.Jn=function $Li(a){WLi(this.a)};var VTb=AMd(2843);S2c(2844,1,tFn,_Li);_.zm=function aMi(){Jae(this.a.c.a.Ug)};var WTb=AMd(2844);S2c(627,1,m6n);_.xm=function hMi(){eMi((new iMi(this)).a)};S2c(2898,1,VEn,iMi);_.zm=function jMi(){eMi(this.a)};var YTb=AMd(2898);Jvn(Il)(3);\n//# sourceURL=rstudio-3.js\n")
