$wnd.rstudio.runAsyncCallback16("function OCk(a){this.a=a}\nfunction lBk(a,b){this.a=a;this.b=b;Rne.call(this)}\nfunction QAk(a,b){a.a=b;bCk(a.n,MAk(a,null),a.a.file_path)}\nfunction SAk(a,b){b.slide_index==0&&cQi(a.n);a.a=b;bCk(a.n,MAk(a,null),a.a.file_path)}\nfunction YAk(a){Vnf('Opening Presentation...',kBd());hIf(a.c,new cKf,false)}\nfunction NAk(a){var b;b=f_f(new g_f(0,'Closing Presentation...'));jWh(a.j,new lBk(a,b))}\nfunction jWh(a,b){d_h(a,Sdo,'close_presentation_pane',new nH,b)}\nfunction XAk(a){var b;a.G.RH();!!a.a&&a.a.active&&(b=Rke(nh(a.n.d).contentWindow),!(!kOd(DFn,b)&&!kOd('javascript:void(0)',b)))&&QAk(a,a.a)}\nfunction KCk(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=yDk(a.a.b.a);NKi(a.a,a.a.a)}switch(a.c){case 1:NAk((c=a.a.a,a.b[0],c));break;case 2:SAk(a.a.a,a.b[0]);break;case 3:a.a.a.G.PH();break;case 4:a.a.a.G.QH();break;case 5:XAk(a.a.a);break;case 6:YAk((b=a.a.a,a.b[0],b));break;case 7:a.a.a.G.SH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nS2c(6903,31,{},lBk);_.Au=function nBk(a){var b;hIf((b=this,a,b).a.c,new cKf,false)};_.zu=function mBk(a){x$f(this.b,a.a?a.a.c:a.d)};var Qlc=AMd(6903);S2c(453,1,m6n);_.xm=function NCk(){KCk((new OCk(this)).a)};S2c(6445,1,VEn,OCk);_.zm=function PCk(){KCk(this.a)};var nmc=AMd(6445);Jvn(Il)(16);\n//# sourceURL=rstudio-16.js\n")
