$wnd.rstudio.runAsyncCallback3("function SLi(a){var b;Dvn[b=++Evn]=SLi;this.a=(Fvn[b]=pwn,a);Evn=b-1}\nfunction ULi(a){var b;Dvn[b=++Evn]=ULi;this.a=(Fvn[b]=ezn,a);Evn=b-1}\nfunction bMi(a){var b;Dvn[b=++Evn]=bMi;this.a=(Fvn[b]=Uvn,a);Evn=b-1}\nfunction dxe(a,b){var c,d;Dvn[d=++Evn]=dxe;for(Fvn[d]=HAn,c=0;(Fvn[d]=HAn,c)<(Fvn[d]=hEn,a.p.a).length;Fvn[d]=HAn,c++){if(sld((Fvn[d]=cEn,a).p,c).zP==b){Uze((Fvn[d]=Vxn,(Fvn[d]=_xn,a).s),sNd((Gvn=(Fvn[d]=_xn,c),Fvn[d]=Vxn,Gvn)));break}}Evn=d-1}\nfunction RLi(a,b){var c;Dvn[c=++Evn]=RLi;this.c=(Fvn[c]=mxn,a);this.b=(Gvn=kvi((Fvn[c]=IAn,a).c,T4o,U4o,(Gvn=Geo,Fvn[c]=sTn,Gvn)),Fvn[c]=IAn,Gvn).BH();this.a=(Gvn=kvi((Fvn[c]=Iwn,a).c,V4o,W4o,(Gvn=X4o,Fvn[c]=vTn,Gvn)),Fvn[c]=Iwn,Gvn).BH();$h((Fvn[c]=pwn,b),new SLi(this),(Gvn=(Fvn[c]=twn,vD)?vD:(vD=new QA),Fvn[c]=hQn,Gvn));Evn=c-1}\nfunction PLi(a){var b,c;Dvn[c=++Evn]=PLi;b=QLi((Fvn[c]=qwn,a),'weaving Rnw files',(Fvn[c]=aCn,a).b,(Gvn=kvi((Fvn[c]=ryn,a).c.c,T4o,U4o,(Gvn=Geo,Fvn[c]=sTn,Gvn)),Fvn[c]=qwn,Gvn));(Fvn[c]=Swn,b)||QLi((Fvn[c]=$Bn,a),'LaTeX typesetting',(Fvn[c]=Uwn,a).a,(Gvn=kvi((Fvn[c]=XAn,a).c.c,V4o,W4o,(Gvn=X4o,Fvn[c]=vTn,Gvn)),Fvn[c]=$Bn,Gvn));Evn=c-1}\nfunction NLi(a,b,c){var d,e;Dvn[e=++Evn]=NLi;Fvn[e]=iBn,d=wGi((Fvn[e]=eJn,(Fvn[e]=iBn,a).b.a));ixe((Fvn[e]=Rwn,d),(Gvn=Kxi(GPg((Fvn[e]=Nyn,(Fvn[e]=Mxn,Iyf(),(Fvn[e]=Rwn,Hyf)).a))),Fvn[e]=Rwn,Gvn));!(Fvn[e]=sAn,!(Fvn[e]=Wwn,b))&&dxe((Fvn[e]=swn,d),b);oxe((Fvn[e]=rwn,d),c);dpe((Fvn[e]=Pvn,d),(Gvn=true,Fvn[e]=YDn,Gvn));new RLi((Fvn[e]=Ywn,a),d);((Fvn[e]=kwn,iFf())||!!(Fvn[e]=LAn,$wnd).remoteDesktop)&&(Fvn[e]=fwn,mFf());Evn=e-1}\nfunction ZLi(b){var c,d;Dvn[c=++Evn]=ZLi;try{if((Fvn[c]=Zvn,b).c<0){d=true;return}(Fvn[c]=bAn,!(Fvn[c]=Qwn,b).a.a)&&(Fvn[c]=nwn,(Fvn[c]=nwn,b).a.a=SSi((Fvn[c]=dJn,b.a.b.a)));switch((Fvn[c]=own,b).c){case 1:NLi((Fvn[c]=Hyn,b).a.a,null,(Gvn=true,Fvn[c]=Fyn,Gvn));break;case 2:NLi((Fvn[c]=Wwn,b).a.a,b.b[0],_Ld(b.b[1]));}}catch(a){a=i2c(a);Evn=(Fvn[c]=ixn,c);throw j2c(a)}finally{(Fvn[c]=twn,b).c<=0&&b.b[0]!=null&&b.b[0].zm();d&&(Evn=c-1)}Evn=c-1}\nfunction QLi(a,b,c,d){var e;Dvn[e=++Evn]=QLi;if(UJ((Fvn[e]=KDn,c))!==UJ(d.BH())&&UJ((Fvn[e]=SBn,d).Gq())!==UJ(d.BH())){R4d(2,'Project Option Unchanged','You changed the global option for '+(Fvn[e]=czn,b)+vco+(Fvn[e]=dzn,d).BH()+', however the current project is '+'still configured to use '+(Fvn[e]=OAn,d).Gq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new ULi((Fvn[e]=ezn,a)),(Gvn=true,Fvn[e]=Iyn,Gvn));Evn=e-1;return true}else{Evn=e-1;return false}Evn=e-1}\nL2c(2841,1,{},RLi);var QTb=tMd(2841);L2c(2842,1,O9n,SLi);_.Gn=function TLi(a){var b;Dvn[b=++Evn]=TLi;PLi((Fvn[b]=pwn,this.a));Evn=b-1};var OTb=tMd(2842);L2c(2843,1,tdo,ULi);_.zm=function VLi(){var a;Dvn[a=++Evn]=VLi;Cae((Gvn=(Fvn[a]='6341',(Fvn[a]=ezn,this.a).c.a.Ug),Fvn[a]=ezn,Gvn));Evn=a-1};var PTb=tMd(2843);L2c(627,1,uKo);_.xm=function aMi(){var a;Dvn[a=++Evn]=aMi;ZLi((Fvn[a]=Yvn,(new bMi((Gvn=this,Fvn[a]=Uvn,Gvn))).a));Evn=a-1};L2c(2897,1,Vco,bMi);_.zm=function cMi(){var a;Dvn[a=++Evn]=cMi;ZLi((Fvn[a]=Yvn,this.a));Evn=a-1};var RTb=tMd(2897);Cvn(Kl)(3);\n//# sourceURL=rstudio-3.js\n")
