$wnd.rstudio.runAsyncCallback22("function SWj(a){this.a=a}\nfunction jWj(a,b){this.a=a;this.b=b}\nfunction XVj(a,b){a.k?w_d(4,'Stop R Markdown Rendering',\"The rendering of '\"+a.g+\"' is in progress. Do you \"+'want to terminate and close the tab?',false,new jWj(a,b),null,null,KDn,Sgn,true):b.zm()}\nfunction OWj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=UWj(a.a.b.a);Aoi(a.a,a.a.a)}switch(a.c){case 1:Cyi(a.a.a,a.b[0]);break;case 2:XVj(a.a.a,a.b[0]);break;case 3:YVj(a.a.a);break;case 4:a.a.a.G.AF();break;case 5:a.a.a.G.BF();break;case 6:ZVj(a.a.a,a.b[0]);break;case 7:$Vj(a.a.a,a.b[0]);break;case 8:_Vj(a.a.a,a.b[0]);break;case 9:aWj(a.a.a,a.b[0]);break;case 10:a.a.a.G.CF();break;case 11:a.a.a.G.DF();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nN$c(6933,1,Ygn,jWj);_.zm=function kWj(){bWj(this.a);this.b.zm()};var bdc=dHd(6933);N$c(315,1,EGn);_.xm=function RWj(){OWj((new SWj(this)).a)};N$c(6431,1,ygn,SWj);_.zm=function TWj(){OWj(this.a)};var kdc=dHd(6431);u7m(Gl)(22);\n//# sourceURL=rstudio-22.js\n")
