$wnd.rstudio.runAsyncCallback20("function H8j(a){this.a=a}\nfunction L8j(a){this.a=a}\nfunction D9j(a){this.a=a}\nfunction P8j(a,b){this.a=a;this.b=b}\nfunction d8j(a){h8j(a,false);Y0f(a.a)}\nfunction z8j(a){a.H.aI();Hm((Am(),zm),new L8j(a))}\nfunction xXh(a,b){p0h(a,dfo,'compile_pdf_closed',new nH,b)}\nfunction E$h(a,b){p0h(a,dfo,'is_compile_pdf_running',new nH,b)}\nfunction q8j(a,b){var c;c=new N1d(b,new H8j(a));E$h(a.d,new J8j(a,c))}\nfunction J8j(a,b){this.a=a;this.b=b;Y$f.call(this,'Closing Compile PDF...')}\nfunction r8j(a,b){Zh(a.g,new rme(false));d8j(a.g);p8j(a,b.target_file);j8j(a.g,O0f(1,b.output));b.errors.length>0&&i8j(a.g,b.errors);b.running||e8j(a.g);k3e(a.g.a.c.c)}\nfunction z9j(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=M9j(a.a.b.a);ZLi(a.a,a.a.a)}switch(a.c){case 1:$Vi(a.a.a,a.b[0]);break;case 2:q8j(a.a.a,a.b[0]);break;case 3:r8j(a.a.a,a.b[0]);break;case 4:u8j(a.a.a);break;case 5:a.a.a.H.ZH();break;case 6:a.a.a.H._H();break;case 7:v8j(a.a.a,a.b[0]);break;case 8:w8j(a.a.a,a.b[0]);break;case 9:x8j(a.a.a,a.b[0]);break;case 10:y8j(a.a.a,a.b[0]);break;case 11:p8j(a.a.a,a.b[0].a.target_file);break;case 12:z8j(a.a.a);break;case 13:a.a.a.H.bI();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nd3c(6974,1,fGn,H8j);_.zm=function I8j(){xXh(this.a.d,new xBf)};var fec=NMd(6974);d3c(6975,383,{},J8j);_.nm=function K8j(a){(g0d(a),a)?j5d(2,'Stop Running Compile','There is a PDF compilation currently running. If you close the Compile PDF tab it will be terminated. Are you sure you want to stop the running PDF compilation?',new P8j(this.a,this.b),false):M1d(this.b)};var gec=NMd(6975);d3c(6976,1,fGn,L8j);_.zm=function M8j(){k3e(this.a.g.a.c.c)};var hec=NMd(6976);d3c(6978,1,FGn,P8j);_.zm=function Q8j(){A8j(this.a,this.b)};var jec=NMd(6978);d3c(290,1,x7n);_.xm=function C9j(){z9j((new D9j(this)).a)};d3c(6480,1,fGn,D9j);_.zm=function E9j(){z9j(this.a)};var vec=NMd(6480);Wwn(Il)(20);\n//# sourceURL=rstudio-20.js\n")
