$wnd.rstudio.runAsyncCallback9("function ivj(a){this.a=a}\nfunction auj(a){a.G.CF();lQe(a.i.n)}\nfunction $tj(a){Sti(a.i);qGf(a.a,'Load History','loadhistory')}\nfunction _tj(a){Sti(a.i);vGf(a.a,'Save History As','.Rhistory',false,'savehistory')}\nfunction evj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=Nvj(a.a.b.a);Aoi(a.a,a.a.a)}switch(a.c){case 1:a.a.a.G.AF();break;case 2:a.a.a.G.BF();break;case 3:$tj(a.a.a);break;case 4:_tj(a.a.a);break;case 5:auj(a.a.a);break;case 6:a.a.a.G.DF();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nN$c(508,1,EGn);_.xm=function hvj(){evj((new ivj(this)).a)};N$c(6323,1,ygn,ivj);_.zm=function jvj(){evj(this.a)};var r6b=dHd(6323);u7m(Gl)(9);\n//# sourceURL=rstudio-9.js\n")
