$wnd.rstudio.runAsyncCallback26("function rzj(){}\nfunction Uzj(a){this.a=a}\nfunction kzj(a,b){gCj(a.c,b)}\nfunction dzj(a,b){var c,d;c=aDj(BFj(a.d.a));if(c.a.length==0){pJj(a.b,false);b.zm()}d=XVd(YVd(new bWd(null,new WSd(c)),new rzj));if(A$c(d,0)>0){u$c().OA(1,'Local Jobs Still Running','The Jobs tab cannot be closed while there '+(A$c(d,1)>0?'are unfinished local jobs':'is an unfinished local job')+'.'+'\\n\\nWait until all local jobs have completed.').PA();return}pJj(a.b,false);b.zm()}\nfunction Qzj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=LFj(a.a.b.a);Mpi(a.a,a.a.a)}switch(a.c){case 1:dzj(a.a.a,a.b[0]);break;case 2:ezj(a.a.a);break;case 3:a.a.a.H.KF();break;case 4:a.a.a.H.LF();break;case 5:fzj(a.a.a,a.b[0]);break;case 6:gzj(a.a.a,a.b[0]);break;case 7:hzj(a.a.a,a.b[0]);break;case 8:izj(a.a.a,a.b[0]);break;case 9:jzj(a.a.a,a.b[0]);break;case 10:a.a.a.H.MF();break;case 11:a.a.a.H.NF();break;case 12:kzj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\n$$c(6958,1,{},rzj);_.ps=function szj(a){return a.type==1&&a.state==2};var p7b=qHd(6958);$$c(318,1,QHn);_.xm=function Tzj(){Qzj((new Uzj(this)).a)};$$c(6464,1,Lhn,Uzj);_.zm=function Vzj(){Qzj(this.a)};var w7b=qHd(6464);H8m(Gl)(26);\n//# sourceURL=rstudio-26.js\n")
