$wnd.rstudio.runAsyncCallback3("function jNi(a){this.a=a}\nfunction lNi(a){this.a=a}\nfunction uNi(a){this.a=a}\nfunction xxe(a,b){var c;for(c=0;c<a.p.a.length;c++){if(Mld(a.p,c).MP==b){mAe(a.s,MNd(c));break}}}\nfunction iNi(a,b){this.c=a;this.b=Dwi(a.c,bmo,cmo,JHn).OH();this.a=Dwi(a.c,dmo,emo,fmo).OH();Yh(b,new jNi(this),AD?AD:(AD=new VA))}\nfunction gNi(a){var b;b=hNi(a,'weaving Rnw files',a.b,Dwi(a.c.c,bmo,cmo,JHn));b||hNi(a,'LaTeX typesetting',a.a,Dwi(a.c.c,dmo,emo,fmo))}\nfunction eNi(a,b,c){var d;d=PHi(a.b.a);Cxe(d,bzi(ZQg((azf(),_yf).a)));!!b&&xxe(d,b);Ixe(d,c);xpe(d,true);new iNi(a,d);(CFf()||!!$wnd.remoteDesktop)&&GFf()}\nfunction qNi(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=jUi(a.a.b.a));switch(a.c){case 1:eNi(a.a.a,null,true);break;case 2:eNi(a.a.a,a.b[0],tMd(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nfunction hNi(a,b,c,d){if(ZJ(c)!==ZJ(d.OH())&&ZJ(d.Jq())!==ZJ(d.OH())){j5d(2,'Project Option Unchanged','You changed the global option for '+b+HFn+d.OH()+', however the current project is '+'still configured to use '+d.Jq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new lNi(a),true);return true}else{return false}}\nd3c(2848,1,{},iNi);var hUb=NMd(2848);d3c(2849,1,cEn,jNi);_.Jn=function kNi(a){gNi(this.a)};var fUb=NMd(2849);d3c(2850,1,FGn,lNi);_.zm=function mNi(){Wae(this.a.c.a.Ug)};var gUb=NMd(2850);d3c(628,1,x7n);_.xm=function tNi(){qNi((new uNi(this)).a)};d3c(2904,1,fGn,uNi);_.zm=function vNi(){qNi(this.a)};var iUb=NMd(2904);Wwn(Il)(3);\n//# sourceURL=rstudio-3.js\n")
