$wnd.rstudio.runAsyncCallback16("function _Dk(a){this.a=a}\nfunction yCk(a,b){this.a=a;this.b=b;coe.call(this)}\nfunction bCk(a,b){a.a=b;oDk(a.o,ZBk(a,null),a.a.file_path)}\nfunction dCk(a,b){b.slide_index==0&&oRi(a.o);a.a=b;oDk(a.o,ZBk(a,null),a.a.file_path)}\nfunction jCk(a){gof('Opening Presentation...',xBd());xIf(a.c,new sKf,false)}\nfunction $Bk(a){var b;b=v_f(new w_f(0,'Closing Presentation...'));vXh(a.k,new yCk(a,b))}\nfunction vXh(a,b){p0h(a,dfo,'close_presentation_pane',new nH,b)}\nfunction iCk(a){var b;a.H.aI();!!a.a&&a.a.active&&(b=cle(nh(a.o.d).contentWindow),!(!xOd(PGn,b)&&!xOd('javascript:void(0)',b)))&&bCk(a,a.a)}\nfunction XDk(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=LEk(a.a.b.a);ZLi(a.a,a.a.a)}switch(a.c){case 1:$Bk((c=a.a.a,a.b[0],c));break;case 2:dCk(a.a.a,a.b[0]);break;case 3:a.a.a.H.ZH();break;case 4:a.a.a.H._H();break;case 5:iCk(a.a.a);break;case 6:jCk((b=a.a.a,a.b[0],b));break;case 7:a.a.a.H.bI();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nd3c(6915,31,{},yCk);_.Au=function ACk(a){var b;xIf((b=this,a,b).a.c,new sKf,false)};_.zu=function zCk(a){N$f(this.b,a.a?a.a.c:a.d)};var amc=NMd(6915);d3c(453,1,x7n);_.xm=function $Dk(){XDk((new _Dk(this)).a)};d3c(6457,1,fGn,_Dk);_.zm=function aEk(){XDk(this.a)};var zmc=NMd(6457);Wwn(Il)(16);\n//# sourceURL=rstudio-16.js\n")
