$wnd.rstudio.runAsyncCallback7("function JVj(a){this.a=a}\nfunction TUj(a,b){this.a=a;this.b=b}\nfunction PUj(a,b){b==null?$5d(a,Zto):$5d(a,b)}\nfunction cVj(a,b){Zh(a.d,new Cge(false));VUj(a.d,b,0)}\nfunction sDh(a,b){TEh(a,WNn,'markers_tab_closed',new vE,b)}\nfunction QUj(a,b){var c,d,e,f,g,h,i;d=a.p;Vrd(d.n);for(g=b,h=0,i=g.length;h<i;++h){f=g[h];c=new TUj(a,f);e=new f0c(d0c(new e0c,f).a.a);x1e(d,new atd(e,c))}}\nfunction VUj(a,b,c){var d;xfg(a.b);PUj(a.c,null);QUj(a.c,kG(eG(JU,1),e8m,2,6,[]));if(b.markers){d=b.markers;Bfg(a.b,null,d.base_path,d.markers,c,false);QUj(a.c,Zne(b.names));PUj(a.c,d.name)}}\nfunction bVj(a,b){var c,d,e,f,g;g=b.a.markers_state;if(g.markers){Zh(a.d,new Cge(true));VUj(a.d,b.a.markers_state,b.a.auto_select);e=g.markers;if(e){d=e.markers;if(d.length>0){f=null;c=b.a.auto_select;c==1?(f=d[0]):c==2&&(f=jfg(d));!!f&&AYf(a.b,(Aie(),Sie(f.path,false,-1,0)),i$d(f.line,f.column),false)}}}else{Zh(a.d,new vge)}}\nfunction FVj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=SVj(a.a.b.a);Aoi(a.a,a.a.a)}switch(a.c){case 1:aVj(a.a.a);break;case 2:a.a.a.G.AF();break;case 3:a.a.a.G.BF();break;case 4:sDh(a.a.a.c,new Vhf);break;case 5:bVj(a.a.a,a.b[0]);break;case 6:a.a.a.G.CF();break;case 7:a.a.a.G.DF();break;case 8:cVj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nN$c(7516,1,Y9m,TUj);_.zm=function UUj(){bB(this.a,this.b)};var Hcc=dHd(7516);N$c(425,1,EGn);_.xm=function IVj(){FVj((new JVj(this)).a)};N$c(6207,1,ygn,JVj);_.zm=function KVj(){FVj(this.a)};var Ucc=dHd(6207);u7m(Gl)(7);\n//# sourceURL=rstudio-7.js\n")
