$wnd.rstudio.runAsyncCallback7("function WWj(a){this.a=a}\nfunction eWj(a,b){this.a=a;this.b=b}\nfunction aWj(a,b){b==null?l6d(a,jvo):l6d(a,b)}\nfunction pWj(a,b){Zh(a.d,new Pge(false));gWj(a.d,b,0)}\nfunction EEh(a,b){dGh(a,hPn,'markers_tab_closed',new vE,b)}\nfunction bWj(a,b){var c,d,e,f,g,h,i;d=a.p;gsd(d.n);for(g=b,h=0,i=g.length;h<i;++h){f=g[h];c=new eWj(a,f);e=new s0c(q0c(new r0c,f).a.a);K1e(d,new ntd(e,c))}}\nfunction gWj(a,b,c){var d;Hgg(a.b);aWj(a.c,null);bWj(a.c,kG(eG(JU,1),r9m,2,6,[]));if(b.markers){d=b.markers;Lgg(a.b,null,d.base_path,d.markers,c,false);bWj(a.c,koe(b.names));aWj(a.c,d.name)}}\nfunction oWj(a,b){var c,d,e,f,g;g=b.a.markers_state;if(g.markers){Zh(a.d,new Pge(true));gWj(a.d,b.a.markers_state,b.a.auto_select);e=g.markers;if(e){d=e.markers;if(d.length>0){f=null;c=b.a.auto_select;c==1?(f=d[0]):c==2&&(f=tgg(d));!!f&&QYf(a.b,(Nie(),dje(f.path,false,-1,0)),v$d(f.line,f.column),false)}}}else{Zh(a.d,new Ige)}}\nfunction SWj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=dXj(a.a.b.a);Mpi(a.a,a.a.a)}switch(a.c){case 1:nWj(a.a.a);break;case 2:a.a.a.H.KF();break;case 3:a.a.a.H.LF();break;case 4:EEh(a.a.a.c,new gif);break;case 5:oWj(a.a.a,a.b[0]);break;case 6:a.a.a.H.MF();break;case 7:a.a.a.H.NF();break;case 8:pWj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\n$$c(7528,1,kbn,eWj);_.zm=function fWj(){bB(this.a,this.b)};var Tcc=qHd(7528);$$c(425,1,QHn);_.xm=function VWj(){SWj((new WWj(this)).a)};$$c(6219,1,Lhn,WWj);_.zm=function XWj(){SWj(this.a)};var edc=qHd(6219);H8m(Gl)(7);\n//# sourceURL=rstudio-7.js\n")
