$wnd.rstudio.runAsyncCallback3("function Yqi(a){this.a=a}\nfunction $qi(a){this.a=a}\nfunction hri(a){this.a=a}\nfunction Ure(a,b){var c;for(c=0;c<a.p.a.length;c++){if(ahd(a.p,c).WM==b){rte(a.s,pId(c));break}}}\nfunction Xqi(a,b){this.c=a;this.b=qai(a.c,CVn,DVn,pjn).zF();this.a=qai(a.c,EVn,FVn,GVn).zF();Yh(b,new Yqi(this),IA?IA:(IA=new by))}\nfunction Vqi(a){var b;b=Wqi(a,'weaving Rnw files',a.b,qai(a.c.c,CVn,DVn,pjn));b||Wqi(a,'LaTeX typesetting',a.a,qai(a.c.c,EVn,FVn,GVn))}\nfunction Tqi(a,b,c){var d;d=Cli(a.b.a);Zre(d,Qci(Nwg((Lff(),Kff).a)));!!b&&Ure(d,b);dse(d,c);Vje(d,true);new Xqi(a,d);(lmf()||!!$wnd.remoteDesktop)&&pmf()}\nfunction dri(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=Zxi(a.a.b.a));switch(a.c){case 1:Tqi(a.a.a,null,true);break;case 2:Tqi(a.a.a,a.b[0],YGd(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nfunction Wqi(a,b,c,d){if(dH(c)!==dH(d.zF())&&dH(d.eq())!==dH(d.zF())){H_d(2,'Project Option Unchanged','You changed the global option for '+b+lhn+d.zF()+', however the current project is '+'still configured to use '+d.eq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new $qi(a),true);return true}else{return false}}\n$$c(2824,1,{},Xqi);var FQb=qHd(2824);$$c(2825,1,Ifn,Yqi);_.fn=function Zqi(a){Vqi(this.a)};var DQb=qHd(2825);$$c(2826,1,jin,$qi);_.zm=function _qi(){s5d(this.a.c.a.Ug)};var EQb=qHd(2826);$$c(627,1,QHn);_.xm=function gri(){dri((new hri(this)).a)};$$c(2880,1,Lhn,hri);_.zm=function iri(){dri(this.a)};var GQb=qHd(2880);H8m(Gl)(3);\n//# sourceURL=rstudio-3.js\n")
