$wnd.rstudio.runAsyncCallback26("function eyj(){}\nfunction Hyj(a){this.a=a}\nfunction Zxj(a,b){VAj(a.c,b)}\nfunction Sxj(a,b){var c,d;c=PBj(oEj(a.d.a));if(c.a.length==0){cIj(a.b,false);b.zm()}d=KVd(LVd(new QVd(null,new JSd(c)),new eyj));if(n$c(d,0)>0){h$c().GA(1,'Local Jobs Still Running','The Jobs tab cannot be closed while there '+(n$c(d,1)>0?'are unfinished local jobs':'is an unfinished local job')+'.'+'\\n\\nWait until all local jobs have completed.').HA();return}cIj(a.b,false);b.zm()}\nfunction Dyj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=yEj(a.a.b.a);Aoi(a.a,a.a.a)}switch(a.c){case 1:Sxj(a.a.a,a.b[0]);break;case 2:Txj(a.a.a);break;case 3:a.a.a.G.AF();break;case 4:a.a.a.G.BF();break;case 5:Uxj(a.a.a,a.b[0]);break;case 6:Vxj(a.a.a,a.b[0]);break;case 7:Wxj(a.a.a,a.b[0]);break;case 8:Xxj(a.a.a,a.b[0]);break;case 9:Yxj(a.a.a,a.b[0]);break;case 10:a.a.a.G.CF();break;case 11:a.a.a.G.DF();break;case 12:Zxj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nN$c(6946,1,{},eyj);_.ps=function fyj(a){return a.type==1&&a.state==2};var d7b=dHd(6946);N$c(318,1,EGn);_.xm=function Gyj(){Dyj((new Hyj(this)).a)};N$c(6452,1,ygn,Hyj);_.zm=function Iyj(){Dyj(this.a)};var k7b=dHd(6452);u7m(Gl)(26);\n//# sourceURL=rstudio-26.js\n")
