$wnd.rstudio.runAsyncCallback15("function JWi(){}\nfunction HWi(a){this.a=a}\nfunction MWi(a){this.a=a}\nfunction OWi(a){this.a=a}\nfunction OXi(a){this.a=a}\nfunction $Vi(a){this.a=a}\nfunction z8f(a){this.a=a}\nfunction DVi(a){PVi(a,new MWi(a))}\nfunction IVi(a){X6f(a.b,new OWi(a))}\nfunction HVi(a){VGk(a.k,new HWi(a),new JWi,W3n)}\nfunction KVi(a){VGk(a.k,new BWi(a,null),new DWi,ibo)}\nfunction LVi(a,b){hIf(a.d,new jcj(b,true),false)}\nfunction g7f(a,b){(V_d(b),b)&&NVi(a.a,S5o,'')}\nfunction aWi(a,b){this.a=a;this.b=b;IDf.call(this)}\nfunction LWi(a,b){LVi(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction NWh(a,b){d_h(a,Sdo,'devtools_load_all_path',new nH,b)}\nfunction PVi(a,b){a.c!=null?LWi(b,a.c):NWh(a.i,new aWi(a,b))}\nfunction JVi(a){a.G.RH();Hm((Am(),zm),new $Vi(a))}\nfunction YVi(){I$f.call(this,'Terminating Build...')}\nfunction X6f(a,b){J6f(a,R5o,R5o,$8f(a.g.b.package_dependencies,'roxygen'),w6f(a,'roxygen'),false,new z8f(b))}\nfunction AVi(a,b){var c,d;K0f(a.p.e,null);d=b.outputs;for(c=0;c<d.length;c++)XUi(a.p,d[c]);b.errors.length>0&&WUi(a.p,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?bbe(a.a.Cj,true,false):J0f(a.p.e);Z2e(a.p.e.c.c)}\nfunction KXi(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=nYi(a.a.b.a);NKi(a.a,a.a.a)}switch(a.c){case 1:AVi(a.a.a,a.b[0]);break;case 2:a.a.a.G.PH();break;case 3:a.a.a.G.QH();break;case 4:NVi(a.a.a,SOo,'');break;case 5:NVi(a.a.a,'build-binary-package','');break;case 6:NVi(a.a.a,'build-source-package','');break;case 7:NVi(a.a.a,'check-package','');break;case 8:NVi(a.a.a,'clean-all','');break;case 9:HVi(a.a.a);break;case 10:NVi(a.a.a,TOo,'');break;case 11:IVi(a.a.a);break;case 12:JVi(a.a.a);break;case 13:KVi(a.a.a);break;case 14:e0h(a.a.a.i,new YVi);break;case 15:NVi(a.a.a,'test-package','');break;case 18:a.a.a.G.SH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nvar R5o='Building package documentation',S5o='roxygenize-package';S2c(2217,1,QEn,z8f);_.vt=function A8f(a){g7f(this.a,a)};var Tlb=AMd(2217);S2c(6888,383,{},YVi);_.nm=function ZVi(a){(V_d(a),a)||g2c().cC(3,'Error Terminating Build','Unable to terminate build. Please try again.').dC()};var JWb=AMd(6888);S2c(6889,1,VEn,$Vi);_.zm=function _Vi(){Z2e(this.a.p.e.c.c)};var KWb=AMd(6889);S2c(6890,54,{},aWi);_.Au=function bWi(a){this.a.c=a;LWi(this.b,this.a.c)};var LWb=AMd(6890);S2c(6881,1,VEn,HWi);_.zm=function IWi(){DVi(this.a)};var _Wb=AMd(6881);S2c(6882,1,VEn,JWi);_.zm=function KWi(){};var aXb=AMd(6882);S2c(6880,1,QEn,MWi);_.vt=function NWi(a){LWi(this,a)};var bXb=AMd(6880);S2c(6883,1,VEn,OWi);_.zm=function PWi(){NVi(this.a,S5o,'')};var cXb=AMd(6883);S2c(252,1,m6n);_.xm=function NXi(){KXi((new OXi(this)).a)};S2c(6429,1,VEn,OXi);_.zm=function PXi(){KXi(this.a)};var yXb=AMd(6429);Jvn(Il)(15);\n//# sourceURL=rstudio-15.js\n")
