$wnd.rstudio.runAsyncCallback9("function MRj(a){this.a=a}\nfunction EQj(a){a.G.RH();m7e(a.i.n)}\nfunction CQj(a){cQi(a.i);IZf(a.a,'Load History','loadhistory')}\nfunction DQj(a){cQi(a.i);NZf(a.a,'Save History As','.Rhistory',false,'savehistory')}\nfunction IRj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=pSj(a.a.b.a);NKi(a.a,a.a.a)}switch(a.c){case 1:a.a.a.G.PH();break;case 2:a.a.a.G.QH();break;case 3:CQj(a.a.a);break;case 4:DQj(a.a.a);break;case 5:EQj(a.a.a);break;case 6:a.a.a.G.SH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nS2c(507,1,m6n);_.xm=function LRj(){IRj((new MRj(this)).a)};S2c(6364,1,VEn,MRj);_.zm=function NRj(){IRj(this.a)};var Y9b=AMd(6364);Jvn(Il)(9);\n//# sourceURL=rstudio-9.js\n")
