$wnd.rstudio.runAsyncCallback7("function uik(a){this.a=a}\nfunction Ehk(a,b){this.a=a;this.b=b}\nfunction Ahk(a,b){b==null?Pbe(a,dYo):Pbe(a,b)}\nfunction Phk(a,b){Zh(a.d,new rme(false));Ghk(a.d,b,0)}\nfunction Q$h(a,b){p0h(a,dfo,'markers_tab_closed',new nH,b)}\nfunction Bhk(a,b){var c,d,e,f,g,h,i;d=a.p;Wwd(d.n);for(g=b,h=0,i=g.length;h<i;++h){f=g[h];c=new Ehk(a,f);e=new G4c(E4c(new F4c,f).a.a);_kf(d,new byd(e,c))}}\nfunction Ghk(a,b,c){var d;_zg(a.b);Ahk(a.c,null);Bhk(a.c,eJ($I(TX,1),Gxn,2,6,[]));if(b.markers){d=b.markers;dAg(a.b,null,d.base_path,d.markers,c,false);Bhk(a.c,Pte(b.names));Ahk(a.c,d.name)}}\nfunction Ohk(a,b){var c,d,e,f,g;g=b.a.markers_state;if(g.markers){Zh(a.d,new rme(true));Ghk(a.d,b.a.markers_state,b.a.auto_select);e=g.markers;if(e){d=e.markers;if(d.length>0){f=null;c=b.a.auto_select;c==1?(f=d[0]):c==2&&(f=Nzg(d));!!f&&hgg(a.b,(poe(),Hoe(f.path,false,-1,0)),Z3d(f.line,f.column),false)}}}else{Zh(a.d,new kme)}}\nfunction qik(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=Dik(a.a.b.a);ZLi(a.a,a.a.a)}switch(a.c){case 1:Nhk(a.a.a);break;case 2:a.a.a.H.ZH();break;case 3:a.a.a.H._H();break;case 4:Q$h(a.a.a.c,new xBf);break;case 5:Ohk(a.a.a,a.b[0]);break;case 6:a.a.a.H.aI();break;case 7:a.a.a.H.bI();break;case 8:Phk(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nd3c(7572,1,zzn,Ehk);_.zm=function Fhk(){VD(this.a,this.b)};var Egc=NMd(7572);d3c(424,1,x7n);_.xm=function tik(){qik((new uik(this)).a)};d3c(6260,1,fGn,uik);_.zm=function vik(){qik(this.a)};var Rgc=NMd(6260);Wwn(Il)(7);\n//# sourceURL=rstudio-7.js\n")
