$wnd.rstudio.runAsyncCallback20("function u7j(a){this.a=a}\nfunction y7j(a){this.a=a}\nfunction q8j(a){this.a=a}\nfunction C7j(a,b){this.a=a;this.b=b}\nfunction S6j(a){W6j(a,false);I0f(a.a)}\nfunction m7j(a){a.G.RH();Hm((Am(),zm),new y7j(a))}\nfunction d7j(a,b){var c;c=new A1d(b,new u7j(a));sZh(a.d,new w7j(a,c))}\nfunction lWh(a,b){d_h(a,Sdo,'compile_pdf_closed',new nH,b)}\nfunction sZh(a,b){d_h(a,Sdo,'is_compile_pdf_running',new nH,b)}\nfunction w7j(a,b){this.a=a;this.b=b;I$f.call(this,'Closing Compile PDF...')}\nfunction e7j(a,b){Zh(a.g,new eme(false));S6j(a.g);c7j(a,b.target_file);Y6j(a.g,y0f(1,b.output));b.errors.length>0&&X6j(a.g,b.errors);b.running||T6j(a.g);Z2e(a.g.a.c.c)}\nfunction m8j(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=z8j(a.a.b.a);NKi(a.a,a.a.a)}switch(a.c){case 1:OUi(a.a.a,a.b[0]);break;case 2:d7j(a.a.a,a.b[0]);break;case 3:e7j(a.a.a,a.b[0]);break;case 4:h7j(a.a.a);break;case 5:a.a.a.G.PH();break;case 6:a.a.a.G.QH();break;case 7:i7j(a.a.a,a.b[0]);break;case 8:j7j(a.a.a,a.b[0]);break;case 9:k7j(a.a.a,a.b[0]);break;case 10:l7j(a.a.a,a.b[0]);break;case 11:c7j(a.a.a,a.b[0].a.target_file);break;case 12:m7j(a.a.a);break;case 13:a.a.a.G.SH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nS2c(6962,1,VEn,u7j);_.zm=function v7j(){lWh(this.a.d,new kBf)};var Vdc=AMd(6962);S2c(6963,383,{},w7j);_.nm=function x7j(a){(V_d(a),a)?Y4d(2,'Stop Running Compile','There is a PDF compilation currently running. If you close the Compile PDF tab it will be terminated. Are you sure you want to stop the running PDF compilation?',new C7j(this.a,this.b),false):z1d(this.b)};var Wdc=AMd(6963);S2c(6964,1,VEn,y7j);_.zm=function z7j(){Z2e(this.a.g.a.c.c)};var Xdc=AMd(6964);S2c(6966,1,tFn,C7j);_.zm=function D7j(){n7j(this.a,this.b)};var Zdc=AMd(6966);S2c(290,1,m6n);_.xm=function p8j(){m8j((new q8j(this)).a)};S2c(6468,1,VEn,q8j);_.zm=function r8j(){m8j(this.a)};var jec=AMd(6468);Jvn(Il)(20);\n//# sourceURL=rstudio-20.js\n")
