$wnd.rstudio.runAsyncCallback22("function qik(a){this.a=a}\nfunction Jhk(a,b){this.a=a;this.b=b}\nfunction vhk(a,b){a.k?$4d(4,'Stop R Markdown Rendering',\"The rendering of '\"+a.g+\"' is in progress. Do you \"+'want to terminate and close the tab?',false,new Jhk(a,b),null,null,w3n,nFn,true):b.zm()}\nfunction mik(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=sik(a.a.b.a);NKi(a.a,a.a.a)}switch(a.c){case 1:OUi(a.a.a,a.b[0]);break;case 2:vhk(a.a.a,a.b[0]);break;case 3:whk(a.a.a);break;case 4:a.a.a.G.PH();break;case 5:a.a.a.G.QH();break;case 6:xhk(a.a.a,a.b[0]);break;case 7:yhk(a.a.a,a.b[0]);break;case 8:zhk(a.a.a,a.b[0]);break;case 9:Ahk(a.a.a,a.b[0]);break;case 10:a.a.a.G.RH();break;case 11:a.a.a.G.SH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nS2c(6974,1,tFn,Jhk);_.zm=function Khk(){Bhk(this.a);this.b.zm()};var Ogc=AMd(6974);S2c(314,1,m6n);_.xm=function pik(){mik((new qik(this)).a)};S2c(6472,1,VEn,qik);_.zm=function rik(){mik(this.a)};var Xgc=AMd(6472);Jvn(Il)(22);\n//# sourceURL=rstudio-22.js\n")
