$wnd.rstudio.runAsyncCallback16("function Jfk(a){var b;B8m[b=++C8m]=Jfk;this.a=(D8m[b]=d9m,a);C8m=b-1}\nfunction gek(a,b){var c;B8m[c=++C8m]=gek;this.a=(D8m[c]=gmn,a);this.b=b;tie.call(this);C8m=c-1}\nfunction Idk(a){var b,c;B8m[c=++C8m]=Idk;b=YHf(new ZHf(0,(E8m='Closing Presentation...',D8m[c]=Lpn,E8m)));cBh((D8m[c]=gmn,a).k,new gek(a,b));C8m=c-1}\nfunction cBh(a,b){var c;B8m[c=++C8m]=cBh;YFh((D8m[c]=Iip,a),Fwo,'close_presentation_pane',(D8m[c]=AJo,new qE),(E8m=(D8m[c]=Iip,b),D8m[c]=BJo,E8m));C8m=c-1}\nfunction Ldk(a,b){var c;B8m[c=++C8m]=Ldk;(D8m[c]=pmn,a).a=b;Yek((D8m[c]=jfn,a).o,Hdk(a,(E8m=null,D8m[c]=Von,E8m)),(E8m=(D8m[c]=F8m,(D8m[c]=jfn,a).a.file_path),D8m[c]=jfn,E8m));C8m=c-1}\nfunction Tdk(a){var b;B8m[b=++C8m]=Tdk;K4e('Opening Presentation...',(D8m[b]=Wgn,Cwd()));_of((D8m[b]=wMn,(D8m[b]=T9m,a).c),new Wqf,(E8m=false,D8m[b]=_8m,E8m));C8m=b-1}\nfunction Ndk(a,b){var c;B8m[c=++C8m]=Ndk;(D8m[c]=N8m,(D8m[c]=jcn,b).slide_index)==0&&Xui((D8m[c]=Q9m,a).o);D8m[c]=pmn,(D8m[c]=dan,a).a=b;Yek((D8m[c]=jfn,(D8m[c]=dan,a).o),Hdk((D8m[c]=dan,a),(E8m=null,D8m[c]=Von,E8m)),(E8m=(D8m[c]=F8m,(D8m[c]=jfn,(D8m[c]=dan,a).a).file_path),D8m[c]=jfn,E8m));C8m=c-1}\nfunction Sdk(a){var b,c;B8m[c=++C8m]=Sdk;(D8m[c]=D9m,(D8m[c]=den,a).H).JF();!(D8m[c]=idn,!(D8m[c]=Pln,a).a)&&(D8m[c]=O8m,(D8m[c]=G8m,a).a.active)&&(b=tfe((E8m=(D8m[c]=dkn,ph((E8m=(D8m[c]=hdn,(D8m[c]=Hen,a).o.d),D8m[c]=z9m,E8m)).contentWindow),D8m[c]=hdn,E8m)),(D8m[c]=Hen,!(!VId(tSn,(D8m[c]=Xdn,b))&&!VId('javascript:void(0)',(D8m[c]=Wgn,b)))))&&Ldk((D8m[c]=Z9m,a),a.a);C8m=c-1}\nfunction Ffk(b){var c,d,e,f;B8m[e=++C8m]=Ffk;try{if((D8m[e]=K8m,b).c<0){f=true;return}if(D8m[e]=Scn,!(D8m[e]=M9m,b).a.a){D8m[e]=Q8m,(D8m[e]=Q8m,b).a.a=tgk((D8m[e]=Dan,b.a.b.a));Fpi((D8m[e]=$9m,b).a,b.a.a)}switch((D8m[e]=Pan,b).c){case 1:Idk((d=(D8m[e]=S8m,b).a.a,b.b[0],d));break;case 2:Ndk((D8m[e]=v9m,b).a.a,b.b[0]);break;case 3:(D8m[e]=Ign,(D8m[e]=b9m,b).a.a.H).HF();break;case 4:(D8m[e]=Ccn,(D8m[e]=gbn,b).a.a.H).IF();break;case 5:Sdk((D8m[e]=hbn,b).a.a);break;case 6:Tdk((c=(D8m[e]=Pdn,b).a.a,b.b[0],c));break;case 7:(D8m[e]=A9m,(D8m[e]=Kgn,b).a.a.H).KF();}}catch(a){a=q$c(a);C8m=(D8m[e]=W9m,e);throw r$c(a)}finally{(D8m[e]=pcn,b).c<=0&&b.b[0]!=null&&b.b[0].zm();f&&(C8m=e-1)}C8m=e-1}\nT$c(6873,31,{},gek);_.yt=function iek(a){var b,c;B8m[c=++C8m]=iek;_of((D8m[c]=wMn,(D8m[c]=afn,(D8m[c]=kon,b=this,a,b).a).c),new Wqf,(E8m=false,D8m[c]=_8m,E8m));C8m=c-1};_.xt=function hek(a){var b;B8m[b=++C8m]=hek;oHf((D8m[b]=eon,this.b),(E8m=(D8m[b]=_9m,a.a)?(D8m[b]=P8m,(D8m[b]=S8m,(D8m[b]=eon,a).a).c):(D8m[b]=u9m,(D8m[b]=eon,a).d),D8m[b]=eon,E8m));C8m=b-1};var fic=jHd(6873);T$c(453,1,Xjo);_.xm=function Ifk(){var a;B8m[a=++C8m]=Ifk;Ffk((D8m[a]=f9m,(new Jfk((E8m=this,D8m[a]=d9m,E8m))).a));C8m=a-1};T$c(6415,1,JRn,Jfk);_.zm=function Kfk(){var a;B8m[a=++C8m]=Kfk;Ffk((D8m[a]=f9m,this.a));C8m=a-1};var Eic=jHd(6415);A8m(Il)(16);\n//# sourceURL=rstudio-16.js\n")
