$wnd.rstudio.runAsyncCallback9("function ZSj(a){this.a=a}\nfunction RRj(a){a.H.aI();z7e(a.i.n)}\nfunction PRj(a){oRi(a.i);YZf(a.a,'Load History','loadhistory')}\nfunction QRj(a){oRi(a.i);b$f(a.a,'Save History As','.Rhistory',false,'savehistory')}\nfunction VSj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=CTj(a.a.b.a);ZLi(a.a,a.a.a)}switch(a.c){case 1:a.a.a.H.ZH();break;case 2:a.a.a.H._H();break;case 3:PRj(a.a.a);break;case 4:QRj(a.a.a);break;case 5:RRj(a.a.a);break;case 6:a.a.a.H.bI();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nd3c(507,1,x7n);_.xm=function YSj(){VSj((new ZSj(this)).a)};d3c(6376,1,fGn,ZSj);_.zm=function $Sj(){VSj(this.a)};var iac=NMd(6376);Wwn(Il)(9);\n//# sourceURL=rstudio-9.js\n")
