$wnd.rstudio.runAsyncCallback9("function vwj(a){this.a=a}\nfunction nvj(a){a.H.MF();yQe(a.i.n)}\nfunction lvj(a){cvi(a.i);GGf(a.a,'Load History','loadhistory')}\nfunction mvj(a){cvi(a.i);LGf(a.a,'Save History As','.Rhistory',false,'savehistory')}\nfunction rwj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=$wj(a.a.b.a);Mpi(a.a,a.a.a)}switch(a.c){case 1:a.a.a.H.KF();break;case 2:a.a.a.H.LF();break;case 3:lvj(a.a.a);break;case 4:mvj(a.a.a);break;case 5:nvj(a.a.a);break;case 6:a.a.a.H.NF();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\n$$c(508,1,QHn);_.xm=function uwj(){rwj((new vwj(this)).a)};$$c(6335,1,Lhn,vwj);_.zm=function wwj(){rwj(this.a)};var D6b=qHd(6335);H8m(Gl)(9);\n//# sourceURL=rstudio-9.js\n")
